# zarrnii-plugin-api

Plugin API for extending **zarrnii**.

This package defines the plugin interface used by the
[zarrnii](https://github.com/khanlab/zarrnii) ecosystem and provides the
hook specifications used by external extensions.

It is primarily intended for developers building plugins that integrate
with `zarrnii`.

For full documentation and source code, see the main repository:

https://github.com/khanlab/zarrnii

## License

MIT

